/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSPageRule.h"
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomCSSPageRule.h"
#include "gdom/GdomCSSRule.h"
#include "gdom/PrivateGdomCSSPageRule.h"
#include "gdom/PrivateGdomCSSRule.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateIntGdomCSSPageRule.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMCSSPageRule::GDOMCSSPageRule(PassRefPtr<WebCore::CSSPageRule> impl)
    : GDOMCSSRule(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "CSSPageRule.h"
#include <gdom/GdomCSSPageRule.h>
#include <gdom/PrivateGdomCSSPageRule.h>
#include <gdom/PrivateIntGdomCSSPageRule.h>
#include <gdom/GdomCSSPageRuleprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomCSSPageRule, gdom_css_page_rule, GDOM_TYPE_CSS_RULE);

/*
struct _GdomCSSPageRulePrivate {
    class WebCore::CSSPageRule *item;
};

#define GDOM_CSS_PAGE_RULE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_CSS_PAGE_RULE, GdomCSSPageRulePrivate))
*/
G_END_DECLS
WebCore::CSSPageRule *
gdom_css_page_rule_get_private(GdomCSSPageRule *request)
{
    GDOMCSSPageRule *res;
    res = static_cast<GDOMCSSPageRule*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::CSSPageRule*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_SELECTOR_TEXT,
    PROP_STYLE,
};


static void gdom_css_page_rule_finalize(GObject* object)
{
    /*GdomCSSPageRule* request = GDOM_CSS_PAGE_RULE(object);*/
    /*GdomCSSPageRulePrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_CSS_RULE));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_css_page_rule_parent_class)->finalize(object);
}

static void gdom_css_page_rule__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomCSSPageRule *self = GDOM_CSS_PAGE_RULE(object);
    WebCore::CSSPageRule * gself = (gdom_css_page_rule_get_private(self));
    switch (prop_id) {
     case PROP_SELECTOR_TEXT:
    {
         WebCore::ExceptionCode ec = 0;
         gself->setSelectorText(WebCore::String::fromUTF8(g_value_get_string (value)) , ec );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_css_page_rule__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomCSSPageRule *self = GDOM_CSS_PAGE_RULE(object);
    WebCore::CSSPageRule * gself = (gdom_css_page_rule_get_private(self));
    switch (prop_id) {
    case PROP_SELECTOR_TEXT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->selectorText()));
         break;
    }
    case PROP_STYLE:
    {
         PassRefPtr<WebCore::CSSStyleDeclaration> ptr = gself->style();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_css_page_rule_class_init(GdomCSSPageRuleClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_css_page_rule_finalize;
    g_klass->set_property = gdom_css_page_rule__set_property_fn;
    g_klass->get_property = gdom_css_page_rule__get_property_fn;

    g_object_class_install_property (g_klass, PROP_SELECTOR_TEXT,
            g_param_spec_string ("selector_text", /* name */
                "css_page_rule_selector_text", /* short description */
                "read-write  gchar * CSSPageRule.selector_text", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_STYLE,
            g_param_spec_object ("style", /* name */
                "css_page_rule_style", /* short description */
                "read-only  GdomCSSStyleDeclaration * CSSPageRule.style", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_CSS_STYLE_DECLARATION, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomCSSPageRulePrivate));*/
}

static void gdom_css_page_rule_init(GdomCSSPageRule* request)
{
    /*GdomCSSPageRulePrivate* priv = GDOM_CSS_PAGE_RULE_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

